@@ -29,13 +29,6 @@ of searches are:
 
     TermExtraction - Term Extraction service
 
-    ListFolders    - List (public) MyWeb folders
-    ListUrls       - List the URLs in a MyWeb folder
-
-    URLSearch      - Search for URLs with particular tags
-    TagSearch      - Search for tags associated with URL or user
-    RelatedTags    - Find tags that appear together on URLs
-
     AlbumSearch    - Find information about albums
     ArtistSearch   - Information on a particular musical performer
     SongDownload   - Find links to various song providers of a song
@@ -53,7 +46,7 @@ specific module documentation.
 Each of these parameter is implemented as an attribute of each
 respective class. For example, you can set parameters like:
 
-    from import yahoo.search.web import WebSearch
+    from yahoo.search.web import WebSearch
 
     app_id = "YahooDemo"
     srch = WebSearch(app_id)
@@ -183,10 +176,10 @@ installer methods above for clarity, the APIs allows you to pass those
 custom handlers as arguments as well (see the documentation below).
 """
 
-__revision__ = "$Id: __init__.py,v 1.16 2007/02/28 05:20:09 zwoop Exp $"
-__version__ = "$Revision: 1.16 $"
+__revision__ = "$Id: __init__.py,v 1.19 2007/09/11 21:38:43 zwoop Exp $"
+__version__ = "$Revision: 1.19 $"
 __author__ = "Leif Hedstrom <leif@ogre.com>"
-__date__ = "Tue Feb 27 22:04:31 MST 2007"
+__date__ = "Tue Sep 11 15:32:26 MDT 2007"
 
 
 import urllib
@@ -197,8 +190,8 @@ import time
 
 from yahoo.search import debug
 
-__revision__ = "$Id: __init__.py,v 1.16 2007/02/28 05:20:09 zwoop Exp $"
-__version__ = "$Revision: 1.16 $"
+__revision__ = "$Id: __init__.py,v 1.19 2007/09/11 21:38:43 zwoop Exp $"
+__version__ = "$Revision: 1.19 $"
 __author__ = "Leif Hedstrom <leif@ogre.com>"
 __date__ = "Thu Jul  7 14:22:16 PDT 2005"
 
@@ -206,7 +199,7 @@ __date__ = "Thu Jul  7 14:22:16 PDT 2005"
 #
 # List of all sub-packages that we expose directly
 #
-__all__ = ["web", "news", "video", "image", "local", "term", "myweb",
+__all__ = ["web", "news", "video", "image", "local", "term",
            "audio", "site"]
 
 
@@ -272,9 +265,8 @@ SUBSCRIPTIONS = {'cr':"Consumer Reports",
 
 
 #
-# Regular expression used to validate the application ID
+# Regular expressions
 #
-APPID_REGEX = re.compile("^[a-zA-Z0-9 _()\[\]*+\-=,.:\\\@]{8,40}$")
 CALLBACK_REGEX = re.compile("^[a-zA-Z0-9\.\[\]\_]+$")
 
 
@@ -482,8 +474,7 @@ _init_valid_params()""" % (self.svc_name)
         return self._app_id
     def _set_app_id(self, app_id):
         """Set the application ID, which is required."""
-        if (isinstance(app_id, types.StringTypes) and
-            (APPID_REGEX.match(app_id) is not None)):
+        if isinstance(app_id, types.StringTypes):
             self._app_id = app_id
         else:
             raise ValueError("""`app_id' can contain \
