@@ -1,7 +1,7 @@
 """ yahoo.search.version - Version information
 """
 
-version = "3.0"
+version = "3.1"
 authorName = "Leif Hedstrom"
 authorMail = "leif@ogre.com"
 maintainerName = "Leif Hedstrom"
@@ -12,10 +12,10 @@ credits = """- The entire Yahoo search team, of course.
 author = "%s <%s>" % (authorName, authorMail)
 
 
-__revision__ = "$Id: version.py,v 1.12 2007/02/28 05:22:43 zwoop Exp $"
-__version__ = "$Revision: 1.12 $"
+__revision__ = "$Id: version.py,v 1.13 2007/09/11 21:49:48 zwoop Exp $"
+__version__ = "$Revision: 1.13 $"
 __author__ = "Leif Hedstrom <leif@ogre.com>"
-__date__ = "Tue Feb 27 22:22:37 MST 2007"
+__date__ = "Tue Sep 11 15:49:27 MDT 2007"
 
 
 
